@@ -82,7 +82,7 @@ use Log::Fine::Levels;
 use Log::Fine::Logger;
 use POSIX qw( strftime );
 
-our $VERSION = '0.40';
+our $VERSION = '0.50';
 
 =head2 Formatters
 
@@ -123,9 +123,9 @@ L<Log::Fine::Formatter>.
                      and not $levelmap) {
                         $levelmap = $map;
                 } elsif (defined $map and not $levelmap) {
-                        _fatal("Log::Fine",
-                                sprintf("Invalid Value: %s"),
-                                $map || "{undef}");
+                        _fatal(
+                                sprintf("Invalid Value: \"%s\"",
+                                        $map || "{undef}"));
                 }
 
                 return $levelmap;
@@ -134,7 +134,7 @@ L<Log::Fine::Formatter>.
 
         sub _logger          { return $loggers }
         sub _objectCount     { return $objcount }
-        sub _incrObjectCount { return ++$objcount; }
+        sub _incrObjectCount { return ++$objcount }
 
 }
 
@@ -253,7 +253,7 @@ sub logger
 
 Private method that is called when a fatal (nonrecoverable) condition
 is encountered.  Will call L<croak|Carp> unless the {no_croak}
-attribute is set.
+attribute is set.  For internal Log::Fine use I<only!>
 
 This method can be overridden per taste.
 
@@ -272,15 +272,27 @@ Message passed to L<croak|Carp>.
 sub _fatal
 {
 
-        my $self = shift;
-        my $msg  = shift;
+        my $self;
+        my $msg;
+        my @call = caller;
 
-        printf STDERR "\n[%s] {%s} FATAL : %s\n",
-            strftime("%c", localtime(time)),
-            ref $self || "{undef}", $msg;
+        # how were we called?
+        if (scalar @_ > 1) {
+                $self = shift;
+                $msg  = shift;
+        } else {
+                $msg = shift;
+        }
+
+        printf STDERR "\n[%s] {%s@%d} FATAL : %s\n",
+            strftime("%c", localtime(time)), $call[0] || "{undef}",
+            $call[2] || 0,
+            $msg || "No reason given";
 
         croak $msg
-            unless $self->{no_croak};
+            unless (    defined $self
+                    and $self->isa("Log::Fine")
+                    and $self->{no_croak});
 
 }          # _fatal()
 
@@ -404,11 +416,11 @@ L<via email|/AUTHOR>.
 
 =head1 REVISION INFORMATION
 
-  $Id: b9da772f65e179d0cb200936ba0a28aa817eebb4 $
+  $Id: 8961739e989b9ecbbe7ca35198a00cb3f74f62d7 $
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2008, 2009, 2010 Christopher M. Fuhrman, 
+Copyright (c) 2008-2011 Christopher M. Fuhrman, 
 All rights reserved.
 
 This program is free software licensed under the...
